/* 
  CESYS Software License - Version 1.0 - January 1st, 2016

  Permission is hereby granted, free of charge, to any person or organization
  obtaining a copy of the software and accompanying documentation covered by
  this license (the "Software") to use, reproduce, display, distribute,
  execute, and transmit the Software, and to prepare derivative works of the
  Software, and to permit third-parties to whom the Software is furnished to
  do so, all subject to the following:

  The software must only be used to operate hardware manufactured by 
  CESYS GmbH, Herzogenaurach.

  The copyright notices in the Software and this entire statement, including
  the above license grant, this restriction and the following disclaimer,
  must be included in all copies of the Software, in whole or in part, and
  all derivative works of the Software, unless such copies or derivative
  works are solely in the form of machine-executable object code generated by
  a source language processor.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
  SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
  FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  DEALINGS IN THE SOFTWARE.
  
  Written by Thomas Hoppe <thomas.hoppe@cesys.com>, 2016
*/

package com.cesys.cebomsr;

/**
 * Class to use when setting multiple outputs simultaneous. Direct construction is prohibited,
 * as the count of the the various elements varies from device type to device type. Instances
 * must be generated calling {@link Device}.createOutputFrame().
 *
 * @author Thomas Hoppe
 */
public final class OutputFrame {
	private final float[] _analogValues;
	private final int[] _digitalValues;

	float[] getAnalogValues() {
		return _analogValues;
	}

	int[] getDigitalValues() {
		return _digitalValues;
	}

	OutputFrame(int anac, int digc) {
		_analogValues = new float[anac];
		_digitalValues = new int[digc];
	}

	/**
	 * Define value that should be set on the specified digital port.
	 * @param index Zero based index of port to specify.
	 * @param value Value to set at this port.
	 */
	public void setDigitalPort(int index, int value) {
		_digitalValues[index] = value;
	}

	/**
	 * Define value that should be set on the specified analog output.
	 * @param index Zero based index of output to specify.
	 * @param value Value to set at this output.
	 */
	public void setAnalogOutput(int index, float value) {
		_analogValues[index] = value;
	}

	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("OutputFrame: \n");
		for (int i = 0; i < _analogValues.length; ++i)
			sb.append(String.format("AnalogOutput #%d = %.2f V \n", i, _analogValues[i]));
		for (int i = 0; i < _digitalValues.length; ++i)
			sb.append(String.format("DigitalPort #%d = %d (0x%02x) \n", i, _digitalValues[i], _digitalValues[i]));
		return sb.toString();
	}
}
